==> open-cluster-management-observability-model-6.1.1-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterobservabilityoperator/apps/v1beta2/MultiClusterObservabilityListFluent.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface MultiClusterObservabilityListFluent<A extends MultiClusterObservabilityListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,MultiClusterObservability item);
  public A setToItems(Integer index,MultiClusterObservability item);
  public A addToItems(io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.MultiClusterObservability... items);
  public A addAllToItems(Collection<MultiClusterObservability> items);
  public A removeFromItems(io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.MultiClusterObservability... items);
  public A removeAllFromItems(Collection<MultiClusterObservability> items);
  public A removeMatchingFromItems(Predicate<MultiClusterObservabilityBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<MultiClusterObservability> getItems();
  public List<MultiClusterObservability> buildItems();
  public MultiClusterObservability buildItem(Integer index);
  public MultiClusterObservability buildFirstItem();
  public MultiClusterObservability buildLastItem();
  public MultiClusterObservability buildMatchingItem(Predicate<MultiClusterObservabilityBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<MultiClusterObservabilityBuilder> predicate);
  public A withItems(List<MultiClusterObservability> items);
  public A withItems(io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.MultiClusterObservability... items);
  public Boolean hasItems();
  public MultiClusterObservabilityListFluent.ItemsNested<A> addNewItem();
  public MultiClusterObservabilityListFluent.ItemsNested<A> addNewItemLike(MultiClusterObservability item);
  public MultiClusterObservabilityListFluent.ItemsNested<A> setNewItemLike(Integer index,MultiClusterObservability item);
  public MultiClusterObservabilityListFluent.ItemsNested<A> editItem(Integer index);
  public MultiClusterObservabilityListFluent.ItemsNested<A> editFirstItem();
  public MultiClusterObservabilityListFluent.ItemsNested<A> editLastItem();
  public MultiClusterObservabilityListFluent.ItemsNested<A> editMatchingItem(Predicate<MultiClusterObservabilityBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,MultiClusterObservabilityFluent<MultiClusterObservabilityListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> open-cluster-management-observability-model-6.7.2-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterobservabilityoperator/apps/v1beta2/MultiClusterObservabilityListFluent.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface MultiClusterObservabilityListFluent<A extends MultiClusterObservabilityListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,MultiClusterObservability item);
  public A setToItems(int index,MultiClusterObservability item);
  public A addToItems(io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.MultiClusterObservability... items);
  public A addAllToItems(Collection<MultiClusterObservability> items);
  public A removeFromItems(io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.MultiClusterObservability... items);
  public A removeAllFromItems(Collection<MultiClusterObservability> items);
  public A removeMatchingFromItems(Predicate<MultiClusterObservabilityBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<MultiClusterObservability> getItems();
  public List<MultiClusterObservability> buildItems();
  public MultiClusterObservability buildItem(int index);
  public MultiClusterObservability buildFirstItem();
  public MultiClusterObservability buildLastItem();
  public MultiClusterObservability buildMatchingItem(Predicate<MultiClusterObservabilityBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<MultiClusterObservabilityBuilder> predicate);
  public A withItems(List<MultiClusterObservability> items);
  public A withItems(io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2.MultiClusterObservability... items);
  public Boolean hasItems();
  public MultiClusterObservabilityListFluent.ItemsNested<A> addNewItem();
  public MultiClusterObservabilityListFluent.ItemsNested<A> addNewItemLike(MultiClusterObservability item);
  public MultiClusterObservabilityListFluent.ItemsNested<A> setNewItemLike(int index,MultiClusterObservability item);
  public MultiClusterObservabilityListFluent.ItemsNested<A> editItem(int index);
  public MultiClusterObservabilityListFluent.ItemsNested<A> editFirstItem();
  public MultiClusterObservabilityListFluent.ItemsNested<A> editLastItem();
  public MultiClusterObservabilityListFluent.ItemsNested<A> editMatchingItem(Predicate<MultiClusterObservabilityBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,MultiClusterObservabilityFluent<MultiClusterObservabilityListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
